# aio_wiki

Asyncio client for interacting with wikimedia APIs

Installation instructions:

```bash
pip install aio_wiki
```

Usage:
```python

from aio_wiki import GraphClient

client = GraphClient()

```

Note
---------
aio_wiki is not affiliated or endorsed by any of the web services it interacts with.